@@ -6,10 +6,11 @@ make.transparent<-function(color,alpha){
 
 ## function to plot a posterior density of trees (e.g., densiTree in phangorn)
 ## written by Liam J. Revell 2016
-densityTree<-function(trees,colors="blue",alpha=NULL,method="plotTree",fix.depth=FALSE,
-	use.edge.length=TRUE,compute.consensus=FALSE,...){
+densityTree<-function(trees,colors="blue",alpha=NULL,method="plotTree",
+	fix.depth=FALSE,use.edge.length=TRUE,compute.consensus=FALSE,...){
 	N<-length(trees)
-	if(any(sapply(trees,function(x) is.null(x$edge.length)))) use.edge.length<-FALSE
+	if(any(sapply(trees,function(x) is.null(x$edge.length)))) 
+		use.edge.length<-FALSE
 	if(!use.edge.length) trees<-lapply(trees,compute.brlen)
 	if(!fix.depth){
 		h<-sapply(trees,function(x) max(nodeHeights(x)))
@@ -18,8 +19,9 @@ densityTree<-function(trees,colors="blue",alpha=NULL,method="plotTree",fix.depth
 		h<-h[ii]
 	}
 	tips<-setNames(1:Ntip(trees[[1]]), 
-		if(compute.consensus) untangle(consensus(trees),"read.tree")$tip.label else 
-		trees[[1]]$tip.label)
+		if(compute.consensus) untangle(consensus(trees),
+			"read.tree")$tip.label 
+		else trees[[1]]$tip.label)
 	if(is.null(alpha)) alpha<-1/N
 	colors<-setNames(sapply(colors,make.transparent,alpha),names(colors))
 	if(method=="plotSimmap") foo<-plotSimmap else foo<-plotTree
